.. _mkdocsmod:

==============
MkDocs modules
==============

DocuBox bundles many MkDocs extension modules.


Theme
=====

* material
* alabaster
* mkdocs-custommill


Extension
=========

* mkdocs-plantuml
* mkdocs-badges
* mkdocs-coverage
